begin;

CREATE SEQUENCE public.sq_gua_id
  INCREMENT 1
  MINVALUE 1
  START 1
  CACHE 1;


CREATE SEQUENCE public.sq_lote_nfce
  INCREMENT 1
  MINVALUE 1
  START 1
  CACHE 1;

CREATE SEQUENCE public.sq_cfg_id
  INCREMENT 1
  MINVALUE 1
  START 1
  CACHE 1;

CREATE TABLE public.guarda
(
  gua_id Integer NOT NULL DEFAULT nextval('sq_gua_id'::regclass),
  gua_codfil char(3) NOT NULL,
  gua_numecf char(3) NOT NULL,
  gua_numnot Integer NOT NULL,
  gua_xml text NOT NULL,
  gua_datinc timestamp without time zone NOT NULL DEFAULT now(),
  gua_datcont timestamp without time zone,
  gua_datenv timestamp without time zone,
  gua_msg varchar(254),
  gua_situacao char(1) NOT NULL,
  CONSTRAINT guarda_pkey PRIMARY KEY (gua_id)
);

CREATE INDEX ilc_gua_datinc
  ON public.guarda
  USING btree
  (gua_datinc);

CREATE INDEX ilc_gua_situacao
  ON public.guarda
  USING btree
  (gua_situacao);

CREATE UNIQUE INDEX iuq_gua_nota
  ON public.guarda
  USING btree
  (gua_codfil, gua_numecf, gua_numnot);

alter table guarda alter column gua_msg type text;

CREATE TABLE public.configuracao
(
  cfg_id Integer NOT NULL DEFAULT nextval('sq_cfg_id'::regclass),
  cfg_config text NOT NULL,
  CONSTRAINT configuracao_pkey PRIMARY KEY (cfg_id)
);

ALTER TABLE public.configuracao ALTER COLUMN cfg_config DROP NOT NULL;

INSERT INTO public.configuracao
(cfg_config)
(SELECT null
  WHERE NOT EXISTS (SELECT 1 AS OK
                      FROM public.configuracao));

CREATE TABLE public.sessao
(
  ses_id integer NOT NULL,
  ses_verlay integer NOT NULL,
  ses_codemp integer NOT NULL,
  ses_useros varchar(30),
  ses_datsol timestamp without time zone,
  ses_nommaq varchar(30),
  ses_verbas integer,
  ses_nomsis varchar(30),
  ses_versis varchar(10),
  ses_assina varchar(256),
  ses_ultace timestamp without time zone,
  CONSTRAINT sessao_pkey PRIMARY KEY (ses_id)
);


-- Tarefa 97626 --
ALTER TABLE public.guarda
  ADD COLUMN gua_modfis CHAR(2);

-- Tarefa 97626 --
ALTER TABLE public.guarda
  ADD COLUMN gua_operacao CHAR(1) DEFAULT 'N';

-- Tarefa 97626 --
ALTER TABLE public.guarda
  ALTER COLUMN gua_operacao SET NOT NULL;

-- Tarefa 97626 --
-- "N": No Definido
-- "O": Outros
-- "V": Venda
-- "C": Cancelamento
ALTER TABLE public.guarda
  ADD CONSTRAINT ck_gua_operacao CHECK (gua_operacao in ('O','N','V','C'));

-- Tarefa 97626 --
ALTER TABLE public.guarda
  ADD COLUMN gua_xmltrn text;

-- Tarefa 97626 --
ALTER TABLE public.guarda
  ADD COLUMN gua_chavea VARCHAR(44);

-- Tarefa 97626 --
-- Nmero de sesso da comunicao com SAT
ALTER TABLE public.guarda
  ADD COLUMN gua_sessao NUMERIC(6);

-- Tarefa 97626 --
DROP INDEX iuq_gua_nota;

-- Tarefa 97626 --
ALTER TABLE public.guarda
  ADD COLUMN gua_serie CHAR(3);

-- Tarefa 97626 --
ALTER TABLE public.guarda
  ADD COLUMN gua_numsat NUMERIC(9);

-- Tarefa 97626 --
ALTER TABLE public.guarda
  ADD COLUMN gua_trnid BIGINT;

-- Tarefa 97626 --
ALTER TABLE public.guarda
  ADD COLUMN gua_cro NUMERIC(5);

-- Tarefa 97626 --
CREATE UNIQUE INDEX iuq_gua_nota_nf
  ON public.guarda
  USING btree
  (gua_codfil, gua_numecf, gua_serie, gua_numnot, gua_cro);

-- Tarefa 97626 --
CREATE UNIQUE INDEX iuq_gua_nota_sat
  ON public.guarda
  USING btree
  (gua_codfil, gua_numecf, gua_numsat, gua_numnot, gua_cro);

-- Tarefa 97626 --
CREATE UNIQUE INDEX iuq_gua_nota_trn
  ON public.guarda
  USING btree
  (gua_codfil, gua_numecf, gua_trnid);

-- Tarefa 97626 --
CREATE SEQUENCE sq_gir_id
  INCREMENT 1
  MINVALUE 1
  START 1
  CACHE 1;

-- Tarefa 97626 --
CREATE TABLE girosat
(
  gir_id Integer NOT NULL DEFAULT nextval('sq_gir_id'::regclass),
  gir_numerosat Integer,
  CONSTRAINT girosat_pkey PRIMARY KEY (gir_id)
);

-- Tarefa 97626 --
INSERT INTO girosat
(gir_numerosat)
(SELECT null
  WHERE NOT EXISTS (SELECT 1 AS OK
                      FROM girosat));

-- Tarefa 97626 --
ALTER TABLE guarda
  ALTER COLUMN gua_numnot DROP NOT NULL;
  
-- Tarefa 97626 --  
ALTER TABLE guarda
  ALTER COLUMN gua_xml DROP NOT NULL;
  
ALTER TABLE guarda
  ADD COLUMN gua_xml_canc TEXT;

  ALTER TABLE guarda
  ADD COLUMN gua_protocolo varchar(20);

end;